
; Tell the AS assembler we want to code for NGPC
;
	cpu	93C141
	maxmode	on
	include	"stddef96.inc"

	include "hardware.inc"  ; Include hardware defines
	include "system.inc"
;
; Define variables
;


START_OF_RAM	EVAL	_MAINRAM
	RAMDW	VBCount
	RAMDD	SMPPTR
	RAMDB	WD

HEADER_OFS	EQU	0200000H

;
; Standard cartridge header
;
	org	HEADER_OFS

	db	" LICENSED BY SNK CORPORATION"	; 28 bytes license string
	dd	Start				; Program Counter
	dw	0				; Catalog number
	db	0				; Sub catalog number
	db	10h				; colour or b+w (10h = colour)
	db	"SAMPLINGTEST"			; Game name (12 bytes)
	dd	0,0,0,0				; padding - reserve for future use

; User Interrupt Vectors

UserIntVect
	dd	nada		; Software Interrupt (SWI 3)
	dd	nada		; Software Interrupt (SWI 4)
	dd	nada		; Software Interrupt (SWI 5)
	dd	nada		; Software Interrupt (SWI 6)
	dd	nada		; RTC Alarm Interrupt
	dd      VBlankInt       ; Vertical Blanking Interrupt
	dd	nada		; Interrupt from Z80
	dd      Timer0		; Timer Interrupt (8 bit timer 0)
	dd	nada		; Timer Interrupt (8 bit timer 1)
	dd	nada		; Timer Interrupt (8 bit timer 2)
	dd	nada		; Timer Interrupt (8 bit timer 3)
	dd	nada		; Serial Transmission Interrupt
	dd	nada		; Serial Reception Interrupt
	dd	nada		; (Reserved)
	dd	nada		; End Micro DMA Int (MicroDMA 0)
	dd	nada		; End Micro DMA Int (MicroDMA 1)
	dd	nada		; End Micro DMA Int (MicroDMA 2)
	dd	nada		; End Micro DMA Int (MicroDMA 3)

nada
	reti

; *** Start of User Code ***

Start
	calr	OS_VERSION      ; Initialize NGP or NGPC mode

	set	6,(rUSERA)      ; User Answer

; Install User Interrupt Vectors

	lda	xix,(UserIntVect)
	lda	xiy,(rSWI3)
	ld	b,18
UIVloop
	ld	xwa,(xix+)
	ld	(xiy+),xwa
	djnz	b,UIVloop


	; set up screen size 160x152
	ld	(08002h),0
	ld	(08003h),0
	ld	(08004h),0a0h
	ld	(08005h),98h

	; set up timer0
	andb	(TRUN),10001110b	;stop count for timer 0
	ldb	(TMOD),02h

	ldb	rw3,VECT_INTLVSET
	ldb	rb3,3
	ldb	rc3,2
	swi	1

	ldb	(WD),0
	ld	xwa,START_SAMPLE
	ld	(SMPPTR),xwa
	calr	initsound

	orb	(TRUN),00000001b	;start count for timer 0

; Enable Interrupts

	ei	0

	; background colour 
	; _BGCPAL = 0xBGR
	ldw	(_BGCPAL), 0036h
	ld	(8118h), 80h

MAIN

; User shutdown? (Power off pressed?)

	cp	(rUSERS),0
	jp	z,Main	; no

; Power off NGP

	ld	rw3,VECT_SHUTDOWN
	calr	SYSTEM_CALL

done
	jr	done

VBlankInt

	; Update Watch Dog Timer to prevent CPU reset
	ld	(rWDCR),WD_CLR
	inc	(VBCount)
	reti

Timer0
	cpb	(WD),0
	jr	nz,out
	ldb	(WD),1
	push	xwa
	push	bc
	ld	xwa,(SMPPTR)
;mono
;	ld	b,(xwa)
;	ld	c,b
;	inc	1,xwa
stereo
	ld	bc,(xwa)
	inc	2,xwa

	cp	xwa,END_SAMPLE
	jr	nz,notend
	ld	xwa,START_SAMPLE
notend
	ld	(SMPPTR),xwa
	ld	(0a2h),bc
	pop	bc
	pop	xwa
	ldb	(WD),0
out
	reti

initsound
	ldw	(000b8h),0aaaah
	ld      xhl,SOUND_DRV
	ld      xde,07000h
	ld      xbc,END_SOUND_DRV - SOUND_DRV
	ldirb	(xde+),(xhl+)
	ldw	(000b8h),055aah
	ret

SYSTEM_CALL
	SystemCallCode
OS_VERSION
	OsVersionCode

SOUND_DRV
	binclude "sndz80.bin"
END_SOUND_DRV

SAMPLE
	binclude "main.wav"
END_SAMPLE
START_SAMPLE	EQU	SAMPLE+58

	; make the cartridge size correct
;	org	HEADER_OFS + 3FFFFFh
;	db	0FFh
